@@ -9,7 +9,7 @@ from .dependency import Dependency
 class Ip(Dependency):
     dependency_required = True
     dependency_name = 'ip'
-    dependency_url = 'apt-get install ip'
+    dependency_url = 'apt-get install iproute2'
 
     @classmethod
     def up(cls, interface, args=[]):
@@ -46,6 +46,6 @@ class Ip(Dependency):
 
         match = re.search(r'([a-fA-F0-9]{2}[-:]){5}[a-fA-F0-9]{2}', output)
         if match:
-           return match.group(0).replace('-', ':')
+            return match.group(0).replace('-', ':')
 
         raise Exception('Could not find the mac address for %s' % interface)
